# Kegbot Pycore

This is Pycore, a standalone command-line Kegbot Core package.  You can use it
to run a Kegbot on any machine supporting Python.

You can find more information at: http://kegbot.org/docs/pycore/

## License and Copyright

All code is offered under the **GPLv2** license, unless otherwise noted.  Please see
``LICENSE.txt`` for the full license.

All code and documentation are **Copyright 2003-2012 Mike Wakerly**, unless otherwise noted.

